==> ginkgo-hpc-docs-1.9.0-4-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/namespacegko_1_1experimental_1_1mpi.js <==
var namespacegko_1_1experimental_1_1mpi =
[
    [ "communicator", "classgko_1_1experimental_1_1mpi_1_1communicator.html", "classgko_1_1experimental_1_1mpi_1_1communicator" ],
    [ "contiguous_type", "classgko_1_1experimental_1_1mpi_1_1contiguous__type.html", "classgko_1_1experimental_1_1mpi_1_1contiguous__type" ],
    [ "environment", "classgko_1_1experimental_1_1mpi_1_1environment.html", "classgko_1_1experimental_1_1mpi_1_1environment" ],
    [ "request", "classgko_1_1experimental_1_1mpi_1_1request.html", "classgko_1_1experimental_1_1mpi_1_1request" ],
    [ "status", "structgko_1_1experimental_1_1mpi_1_1status.html", "structgko_1_1experimental_1_1mpi_1_1status" ],
    [ "type_impl", "structgko_1_1experimental_1_1mpi_1_1type__impl.html", null ],
    [ "type_impl< char >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01char_01_4.html", null ],
    [ "type_impl< double >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01double_01_4.html", null ],
    [ "type_impl< float >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01float_01_4.html", null ],
    [ "type_impl< int >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01int_01_4.html", null ],
    [ "type_impl< long >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01long_01_4.html", null ],
    [ "type_impl< long double >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01long_01double_01_4.html", null ],
    [ "type_impl< long long >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01long_01long_01_4.html", null ],
    [ "type_impl< unsigned >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01_4.html", null ],
    [ "type_impl< unsigned char >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01char_01_4.html", null ],
    [ "type_impl< unsigned long >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01long_01_4.html", null ],
    [ "type_impl< unsigned long long >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01long_01long_01_4.html", null ],
    [ "type_impl< unsigned short >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01short_01_4.html", null ],
    [ "window", "classgko_1_1experimental_1_1mpi_1_1window.html", "classgko_1_1experimental_1_1mpi_1_1window" ],
    [ "thread_type", "namespacegko_1_1experimental_1_1mpi.html#ab7c53f651b07ca2e9cd171981268aefb", [
      [ "serialized", "namespacegko_1_1experimental_1_1mpi.html#ab7c53f651b07ca2e9cd171981268aefbafb741eb55bd67db2031aa661671fba7c", null ],
      [ "funneled", "namespacegko_1_1experimental_1_1mpi.html#ab7c53f651b07ca2e9cd171981268aefba2110cc27d60e873203472314639a3c8a", null ],
      [ "single", "namespacegko_1_1experimental_1_1mpi.html#ab7c53f651b07ca2e9cd171981268aefbadd5c07036f2975ff4bce568b6511d3bc", null ],
      [ "multiple", "namespacegko_1_1experimental_1_1mpi.html#ab7c53f651b07ca2e9cd171981268aefbace495ab8d79db0d37413d8e95b54e606", null ]
    ] ],
    [ "get_walltime", "namespacegko_1_1experimental_1_1mpi.html#a508f97387781bb32dd2c7616dee1a786", null ],
    [ "is_gpu_aware", "namespacegko_1_1experimental_1_1mpi.html#a7b1bbdde143284165fab4380acba4acc", null ],
    [ "map_rank_to_device_id", "namespacegko_1_1experimental_1_1mpi.html#a0ec0c93a068b2c19da8cb5e874bf9f6c", null ],
    [ "requires_host_buffer", "namespacegko_1_1experimental_1_1mpi.html#a379e508c71176773a3f2331cd7975c03", null ],
    [ "wait_all", "namespacegko_1_1experimental_1_1mpi.html#aff5fd80940add1e4f08a53bfcd131b01", null ]
];

==> ginkgo-hpc-docs-1.10.0-2-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/namespacegko_1_1experimental_1_1mpi.js <==
var namespacegko_1_1experimental_1_1mpi =
[
    [ "CollectiveCommunicator", "classgko_1_1experimental_1_1mpi_1_1CollectiveCommunicator.html", "classgko_1_1experimental_1_1mpi_1_1CollectiveCommunicator" ],
    [ "communicator", "classgko_1_1experimental_1_1mpi_1_1communicator.html", "classgko_1_1experimental_1_1mpi_1_1communicator" ],
    [ "contiguous_type", "classgko_1_1experimental_1_1mpi_1_1contiguous__type.html", "classgko_1_1experimental_1_1mpi_1_1contiguous__type" ],
    [ "DenseCommunicator", "classgko_1_1experimental_1_1mpi_1_1DenseCommunicator.html", "classgko_1_1experimental_1_1mpi_1_1DenseCommunicator" ],
    [ "environment", "classgko_1_1experimental_1_1mpi_1_1environment.html", "classgko_1_1experimental_1_1mpi_1_1environment" ],
    [ "NeighborhoodCommunicator", "classgko_1_1experimental_1_1mpi_1_1NeighborhoodCommunicator.html", "classgko_1_1experimental_1_1mpi_1_1NeighborhoodCommunicator" ],
    [ "request", "classgko_1_1experimental_1_1mpi_1_1request.html", "classgko_1_1experimental_1_1mpi_1_1request" ],
    [ "status", "structgko_1_1experimental_1_1mpi_1_1status.html", "structgko_1_1experimental_1_1mpi_1_1status" ],
    [ "type_impl", "structgko_1_1experimental_1_1mpi_1_1type__impl.html", null ],
    [ "type_impl< char >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01char_01_4.html", null ],
    [ "type_impl< double >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01double_01_4.html", null ],
    [ "type_impl< float >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01float_01_4.html", null ],
    [ "type_impl< int >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01int_01_4.html", null ],
    [ "type_impl< long >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01long_01_4.html", null ],
    [ "type_impl< long double >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01long_01double_01_4.html", null ],
    [ "type_impl< long long >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01long_01long_01_4.html", null ],
    [ "type_impl< unsigned >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01_4.html", null ],
    [ "type_impl< unsigned char >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01char_01_4.html", null ],
    [ "type_impl< unsigned long >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01long_01_4.html", null ],
    [ "type_impl< unsigned long long >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01long_01long_01_4.html", null ],
    [ "type_impl< unsigned short >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01short_01_4.html", null ],
    [ "window", "classgko_1_1experimental_1_1mpi_1_1window.html", "classgko_1_1experimental_1_1mpi_1_1window" ],
    [ "comm_index_type", "namespacegko_1_1experimental_1_1mpi.html#a13b7760affb031fee59d385754eaaffb", null ],
    [ "thread_type", "namespacegko_1_1experimental_1_1mpi.html#ab7c53f651b07ca2e9cd171981268aefb", [
      [ "serialized", "namespacegko_1_1experimental_1_1mpi.html#ab7c53f651b07ca2e9cd171981268aefbafb741eb55bd67db2031aa661671fba7c", null ],
      [ "funneled", "namespacegko_1_1experimental_1_1mpi.html#ab7c53f651b07ca2e9cd171981268aefba2110cc27d60e873203472314639a3c8a", null ],
      [ "single", "namespacegko_1_1experimental_1_1mpi.html#ab7c53f651b07ca2e9cd171981268aefbadd5c07036f2975ff4bce568b6511d3bc", null ],
      [ "multiple", "namespacegko_1_1experimental_1_1mpi.html#ab7c53f651b07ca2e9cd171981268aefbace495ab8d79db0d37413d8e95b54e606", null ]
    ] ],
    [ "get_walltime", "namespacegko_1_1experimental_1_1mpi.html#a508f97387781bb32dd2c7616dee1a786", null ],
    [ "is_gpu_aware", "namespacegko_1_1experimental_1_1mpi.html#a7b1bbdde143284165fab4380acba4acc", null ],
    [ "map_rank_to_device_id", "namespacegko_1_1experimental_1_1mpi.html#a0ec0c93a068b2c19da8cb5e874bf9f6c", null ],
    [ "requires_host_buffer", "namespacegko_1_1experimental_1_1mpi.html#a379e508c71176773a3f2331cd7975c03", null ],
    [ "wait_all", "namespacegko_1_1experimental_1_1mpi.html#aff5fd80940add1e4f08a53bfcd131b01", null ]
];
